==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/AndroidDeviceComplianceLocalActionBase.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;


/**
 * <i>“Local Action Configuration”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "gracePeriodInMinutes"})
@JsonInclude(Include.NON_NULL)
public class AndroidDeviceComplianceLocalActionBase extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.androidDeviceComplianceLocalActionBase";
    }

    @JsonProperty("gracePeriodInMinutes")
    protected Integer gracePeriodInMinutes;

    protected AndroidDeviceComplianceLocalActionBase() {
        super();
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    /**
     * <i>“Number of minutes to wait till a local action is enforced. Valid values 0 to
     * 2147483647”</i>
     * 
     * @return property gracePeriodInMinutes
     */
    @Property(name="gracePeriodInMinutes")
    @JsonIgnore
    public Optional<Integer> getGracePeriodInMinutes() {
        return Optional.ofNullable(gracePeriodInMinutes);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code
     * gracePeriodInMinutes} field changed. Field description below. The field name is
     * also added to an internal map of changed fields in the returned object so that
     * when {@code this.patch()} is called (if available)on the returned object only
     * the changed fields are submitted.
     * <p>
     * <i>“Number of minutes to wait till a local action is enforced. Valid values 0 to
     * 2147483647”</i>
     * 
     * @param gracePeriodInMinutes
     *            new value of {@code gracePeriodInMinutes} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code gracePeriodInMinutes} field changed
     */
    public AndroidDeviceComplianceLocalActionBase withGracePeriodInMinutes(Integer gracePeriodInMinutes) {
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.changedFields = changedFields.add("gracePeriodInMinutes");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.androidDeviceComplianceLocalActionBase");
        _x.gracePeriodInMinutes = gracePeriodInMinutes;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidDeviceComplianceLocalActionBase patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidDeviceComplianceLocalActionBase put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private AndroidDeviceComplianceLocalActionBase _copy() {
        AndroidDeviceComplianceLocalActionBase _x = new AndroidDeviceComplianceLocalActionBase();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.gracePeriodInMinutes = gracePeriodInMinutes;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AndroidDeviceComplianceLocalActionBase[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("gracePeriodInMinutes=");
        b.append(this.gracePeriodInMinutes);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/AndroidDeviceComplianceLocalActionBase.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;


/**
 * <i>“Local Action Configuration”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "gracePeriodInMinutes"})
@JsonInclude(Include.NON_NULL)
public class AndroidDeviceComplianceLocalActionBase extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.androidDeviceComplianceLocalActionBase";
    }

    @JsonProperty("gracePeriodInMinutes")
    protected Integer gracePeriodInMinutes;

    protected AndroidDeviceComplianceLocalActionBase() {
        super();
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    /**
     * <i>“Number of minutes to wait till a local action is enforced. Valid values 0 to
     * 2147483647”</i>
     * 
     * @return property gracePeriodInMinutes
     */
    @Property(name="gracePeriodInMinutes")
    @JsonIgnore
    public Optional<Integer> getGracePeriodInMinutes() {
        return Optional.ofNullable(gracePeriodInMinutes);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code
     * gracePeriodInMinutes} field changed. Field description below. The field name is
     * also added to an internal map of changed fields in the returned object so that
     * when {@code this.patch()} is called (if available)on the returned object only
     * the changed fields are submitted.
     * <p>
     * <i>“Number of minutes to wait till a local action is enforced. Valid values 0 to
     * 2147483647”</i>
     * 
     * @param gracePeriodInMinutes
     *            new value of {@code gracePeriodInMinutes} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code gracePeriodInMinutes} field changed
     */
    public AndroidDeviceComplianceLocalActionBase withGracePeriodInMinutes(Integer gracePeriodInMinutes) {
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.changedFields = changedFields.add("gracePeriodInMinutes");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.androidDeviceComplianceLocalActionBase");
        _x.gracePeriodInMinutes = gracePeriodInMinutes;
        return _x;
    }

    public AndroidDeviceComplianceLocalActionBase withUnmappedField(String name, Object value) {
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidDeviceComplianceLocalActionBase patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AndroidDeviceComplianceLocalActionBase put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        AndroidDeviceComplianceLocalActionBase _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private AndroidDeviceComplianceLocalActionBase _copy() {
        AndroidDeviceComplianceLocalActionBase _x = new AndroidDeviceComplianceLocalActionBase();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.gracePeriodInMinutes = gracePeriodInMinutes;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AndroidDeviceComplianceLocalActionBase[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("gracePeriodInMinutes=");
        b.append(this.gracePeriodInMinutes);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
